Registers the pmtiles:// protocol with maplibre-gl so PMTiles archives can be used as map style URLs and tile sources.
Registers the pmtiles:// protocol with maplibre-gl so PMTiles archives can be used as map style URLs and tile sources.
No vars found in this namespace.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |